@@ -116,11 +116,30 @@ foo_sub_interface_class_init (gpointer g_class, gpointer class_data)
                   G_TYPE_NONE);
 }
 
-void foo_sub_interface_do_bar (FooSubInterface *self)
+void
+foo_sub_interface_do_bar (FooSubInterface *self)
 {
   FOO_SUBINTERFACE_GET_INTERFACE(self)->do_bar (self);
 }
 
+void
+foo_sub_interface_do_moo (FooSubInterface *self, int x, gpointer y)
+{
+  FOO_SUBINTERFACE_GET_INTERFACE(self)->do_moo (self, x, y);
+}
+
+/**
+ * foo_sub_interface_do_baz:
+ * @self:
+ * @callback: (scope call):
+ * @user_data:
+ *
+ */
+void
+foo_sub_interface_do_baz (FooSubInterface *self, GCallback callback, gpointer user_data)
+{
+  FOO_SUBINTERFACE_GET_INTERFACE(self)->do_baz (self, callback, user_data);
+}
 
 G_DEFINE_TYPE_EXTENDED (FooObject, foo_object, G_TYPE_OBJECT,
 			0, G_IMPLEMENT_INTERFACE (FOO_TYPE_INTERFACE,
@@ -203,6 +222,12 @@ foo_object_init (FooObject *object)
 
 }
 
+/**
+ * foo_object_external_type:
+ * @object: a #FooObject
+ *
+ * Returns: (transfer none): %NULL always
+ */
 UtilityObject*
 foo_object_external_type (FooObject *object)
 {
@@ -227,6 +252,19 @@ foo_object_is_it_time_yet (FooObject *object, time_t time)
 {
 }
 
+/**
+ * foo_object_new_cookie: (skip)
+ * @object:
+ * @target:
+ *
+ * Not sure why this test is here...
+ */
+FooObjectCookie
+foo_object_new_cookie (FooObject *object, const char *target)
+{
+  return NULL;
+}
+
 const char *
 foo_object_get_name (FooObject *object)
 {
@@ -286,7 +324,7 @@ foo_subobject_init (FooSubobject *object)
  * This function is intended to match clutter_stage_get_default which
  * uses a C sugar return type.
  *
- * Return value: (type FooSubobject): The global #FooSubobject
+ * Return value: (type FooSubobject) (transfer none): The global #FooSubobject
  */
 FooObject *
 foo_object_get_default ()
@@ -449,11 +487,24 @@ void foo_test_unsigned (unsigned int uint)
 {
 }
 
+/**
+ * foo_test_string_array:
+ * @array: (array zero-terminated=1):
+ */
 void
 foo_test_string_array (char **array)
 {
 }
 
+/**
+ * foo_test_string_array_with_g:
+ * @array: (array zero-terminated=1):
+ */
+void
+foo_test_string_array_with_g (gchar **array)
+{
+}
+
 /**
  * foo_test_array:
  * Returns: (element-type utf8) (transfer container):
@@ -464,6 +515,23 @@ foo_test_array (void)
   return NULL;
 }
 
+/**
+ * foo_rectangle_new: (skip)
+ *
+ * This is a C convenience constructor; we have to (skip)
+ * it because it's not a boxed type.
+ */
+FooRectangle *
+foo_rectangle_new (int x, int y, int width, int height)
+{
+  FooRectangle *r = g_slice_new (FooRectangle);
+  r->x = x;
+  r->y = y;
+  r->width = width;
+  r->height = height;
+  return r;
+}
+
 /**
  * foo_rectangle_add:
  * @r1: (inout): add to this rect
@@ -599,16 +667,32 @@ foo_buffer_some_method (FooBuffer *buffer)
 {
 }
 
-#define FOO_DEFINE_SHOULD_NOT_BE_EXPOSED "should not be exposed"
+struct _FooOtherObject
+{
+  GObject parent_instance;
+};
 
-/**
- * FooSkippable: (skip)
- * @FOO_SKIPPABLE_ONE: a skippable enum value
- * @FOO_SKIPPABLE_TWO: another skippable enum value
- *
- * Some type that is only interesting from C and should not be
- * exposed to language bindings.
- */
+struct _FooOtherObjectClass
+{
+  GObjectClass parent_class;
+};
+
+G_DEFINE_TYPE(FooOtherObject, foo_other_object, G_TYPE_OBJECT);
+
+static void
+foo_other_object_class_init (FooOtherObjectClass *klass)
+{
+
+}
+
+static void
+foo_other_object_init (FooOtherObject *object)
+{
+
+}
+
+
+#define FOO_DEFINE_SHOULD_NOT_BE_EXPOSED "should not be exposed"
 
 /**
  * foo_skip_me: (skip)
@@ -626,3 +710,50 @@ foo_skip_me (FooSkippable fs)
  * FooForeignStruct: (foreign)
  *
  */
+
+FooForeignStruct*
+foo_foreign_struct_new (void)
+{
+  return g_slice_new0 (FooForeignStruct);
+}
+
+/**
+ * foo_test_varargs_callback: (skip)
+ *
+ */
+void
+foo_test_varargs_callback (gint i, FooVarargsCallback callback)
+{
+}
+
+/**
+ * foo_test_varargs_callback2: (skip)
+ *
+ */
+void
+foo_test_varargs_callback2 (FooVarargsCallback callback)
+{
+}
+
+/**
+ * foo_test_varargs_callback3: (skip)
+ *
+ */
+void
+foo_test_varargs_callback3 (FooVarargsCallback callback,
+			    FooVarargsCallback callback2)
+{
+}
+
+/**
+ * foo_object_append_new_stack_layer:
+ *
+ * This shouldn't be scanned as a constructor.
+ *
+ * Returns: (transfer none):
+ */
+FooOtherObject *
+foo_object_append_new_stack_layer (FooObject *obj, int x)
+{
+  return NULL;
+}
