@@ -2,6 +2,7 @@
 #define __FOO_OBJECT_H__
 
 #include <glib-object.h>
+#include <gio/gio.h> /* GAsyncReadyCallback */
 #include "utility.h"
 
 #define FOO_SUCCESS_INT 0x1138
@@ -33,6 +34,10 @@
 #define FOO_BUFFER(object)     (G_TYPE_CHECK_INSTANCE_CAST ((object), FOO_TYPE_BUFFER, FooBuffer))
 #define FOO_IS_BUFFER(object)  (G_TYPE_CHECK_INSTANCE_TYPE ((object), FOO_TYPE_BUFFER))
 
+#define FOO_TYPE_OTHER_OBJECT  (foo_other_object_get_type ())
+#define FOO_OTHER_OBJECT(object)     (G_TYPE_CHECK_INSTANCE_CAST ((object), FOO_TYPE_OTHER_OBJECT, FooOtherObject))
+#define FOO_IS_OTHER_OBJECT(object)  (G_TYPE_CHECK_INSTANCE_TYPE ((object), FOO_TYPE_OTHER_OBJECT))
+
 typedef struct _FooInterface       FooInterface;
 typedef struct _FooInterfaceIface  FooInterfaceIface;
 typedef struct _FooSubInterface       FooSubInterface;
@@ -43,6 +48,8 @@ typedef struct _FooSubobject       FooSubobject;
 typedef struct _FooSubobjectClass  FooSubobjectClass;
 typedef struct _FooBuffer          FooBuffer;
 typedef struct _FooBufferClass     FooBufferClass;
+typedef struct _FooOtherObject          FooOtherObject;
+typedef struct _FooOtherObjectClass     FooOtherObjectClass;
 
 struct _FooInterfaceIface
 {
@@ -66,11 +73,20 @@ struct _FooSubInterfaceIface
   /* virtual table */
 
   void (*do_bar) (FooSubInterface *self);
+
+  /* explicitly test un-named parameters */
+  void (*do_moo) (FooSubInterface *self, int, gpointer);
+
+  void (*do_baz) (FooSubInterface *self, GCallback callback, gpointer data);
 };
 
 GType                 foo_sub_interface_get_type       (void) G_GNUC_CONST;
 
 void foo_sub_interface_do_bar (FooSubInterface *self);
+void foo_sub_interface_do_moo (FooSubInterface *self, int, gpointer);
+void foo_sub_interface_do_baz (FooSubInterface *self,
+                               GCallback callback,
+                               gpointer data);
 
 struct _FooObject
 {
@@ -87,6 +103,9 @@ struct _FooObjectClass
 
   /* Intended to match GFile */
   void (*read_fn) (FooObject *object, int offset, int length);
+  
+  /* Test reserved stuff */
+  GCallback _reserved[4];
 };
 
 gint                  foo_init                     (void);
@@ -99,11 +118,6 @@ void                  foo_object_various           (FooObject *object, void *dat
 
 void                  foo_object_take_all          (FooObject *object, int x, ...);
 
-/* A random typedef */
-typedef GSList FooList;
-
-void                  foo_object_with_tdef         (FooObject *object, FooList *blah);
-
 typedef gpointer FooObjectCookie;
 
 FooObjectCookie       foo_object_new_cookie        (FooObject *object, const char *target);
@@ -122,6 +136,8 @@ void                  foo_object_read              (FooObject *object, int offse
 
 int                   foo_object_static_meth       (void);
 
+void                  foo_object_skipped_method    (FooObject *object);
+
 struct _FooSubobject
 {
   FooObject parent_instance;
@@ -141,6 +157,8 @@ GType                 foo_buffer_get_type          (void);
 
 void                  foo_buffer_some_method       (FooBuffer *buffer);
 
+GType                 foo_other_object_get_type    (void) G_GNUC_CONST;
+
 typedef enum
 {
   FOO_ENUM_ALPHA,
@@ -185,6 +203,13 @@ typedef enum
   FOO_ENUM_FULLNAME_THREE
 } FooEnumFullname;
 
+typedef enum
+{
+  FOO_ADDRESS_INVALID,
+  FOO_ADDRESS_IPV4,
+  FOO_ADDRESS_IPV6
+} FooAddressType;
+
 typedef struct _FooBoxed FooBoxed;
 
 GType                 foo_boxed_get_type       (void) G_GNUC_CONST;
@@ -290,23 +315,27 @@ union _FooBUnion
   FooBRect *rect;
 };
 
-typedef union _FooUnion
+typedef union _FooUnion FooUnion;
+
+union _FooUnion
 {
   int foo;
-} FooUnion;
+};
 
 typedef struct _FooUtilityStruct FooUtilityStruct;
 struct _FooUtilityStruct
 {
   UtilityStruct bar;
 };
-typedef struct _FooThingWithArray
+
+typedef struct _FooThingWithArray FooThingWithArray;
+struct _FooThingWithArray
 {
   int x;
   int y;
   char lines[80];
   guchar *data;
-} FooThingWithArray;
+} ;
 
 FooBUnion *foo_bunion_new (void);
 
@@ -321,6 +350,8 @@ void foo_test_string_array (char **array);
 
 void foo_test_string_array_with_g (gchar **array);
 
+GArray *foo_test_array (void);
+
 const char * foo_test_const_char_retval (void);
 const FooStruct * foo_test_const_struct_retval (void);
 void foo_test_const_char_param (const char * param);
@@ -332,6 +363,14 @@ void foo_test_varargs_callback2 (FooVarargsCallback callback);
 void foo_test_varargs_callback3 (FooVarargsCallback callback,
 				 FooVarargsCallback callback2);
 
+/* Make sure callbacks get the right scope by default */
+void foo_async_ready_callback(GCancellable *cancellable,
+                              GAsyncReadyCallback callback,
+                              gpointer user_data);
+void foo_destroy_notify_callback(FooCallback callback,
+                                 gpointer data,
+                                 GDestroyNotify destroy);
+
 typedef enum {
   FOO_ERROR_GOOD,
   FOO_ERROR_BAD,
@@ -363,4 +402,34 @@ typedef enum
 void foo_some_variant (guint x, va_list args);
 void foo_some_variant_ptr (guint x, va_list *args);
 
+/**
+ * FooSkippable: (skip)
+ * @FOO_SKIPPABLE_ONE: a skippable enum value
+ * @FOO_SKIPPABLE_TWO: another skippable enum value
+ *
+ * Some type that is only interesting from C and should not be
+ * exposed to language bindings.
+ */
+typedef enum {
+  FOO_SKIPPABLE_ONE,
+  FOO_SKIPPABLE_TWO
+} FooSkippable;
+void foo_skip_me (FooSkippable fs);
+
+typedef struct _FooForeignStruct           FooForeignStruct;
+
+struct _FooForeignStruct
+{
+  int foo;
+};
+
+FooForeignStruct* foo_foreign_struct_new (void);
+
+/* This one should be a global, not a method on UtilityObject since
+ * it's a separate namespace.
+ */
+void foo_object_a_global_method (UtilityObject *obj);
+
+FooOtherObject * foo_object_append_new_stack_layer (FooObject *obj, int x);
+
 #endif /* __FOO_OBJECT_H__ */
